//
// file      : analog1.c
// author    : Ian Forse
// date      : 06-APR-2004
// purpose   : Analogue read and display on MDM-1
// includes  : pic.h, adc.c, delay.h, delay.c, mdm.c, mdm.h mdm_demo.c
// notes     : Includes display demo mode switchable via RD7.
// compiler  : CCS PCW 3.187
//
// Copyright (C) 2004 Ian Forse
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
// USA


#include <16F877.h>
#device *=16 ADC=10
#fuses HS,NOWDT,NOPROTECT,NOLVP

#define low 0
#define high 1

#use delay(clock=4000000)
#use rs232(baud=19200, xmit=PIN_C6, rcv=PIN_C7)

// Include Files
#include "mdm.h"

// Program Files
#include "mdm.c"
#include "mdm_demo.c"

main()
{
unsigned int8 i, c;
float ADC_FILT;
unsigned int16 ADC_VALUE, ACT_VALUE;
set_tris_d(0b00000001);
mdm_init();
mdm_all(0);

	while(1)
	{
		if (!input(PIN_D0))
		{
         setup_adc_ports( ALL_ANALOG );
         setup_adc(ADC_CLOCK_INTERNAL );
         set_adc_channel( 0 );
         ADC_FILT = 0;           // Clear out previous count
         for (i=0; i<64; i++)
         {
            ADC_VALUE = read_adc();
            ADC_FILT += ADC_VALUE;
         }
         ADC_FILT = (ADC_FILT/64)+0.5;   // Average of 64 readings to reduce noise

         ACT_VALUE = ((int16) (ADC_FILT * 4.883)); // * 4.883 to convert to 0 - 5.0V
         c = (int8) (ACT_VALUE / 1000) + 48;
         mdm_write_p ( 1, c);
         putc(c);
         ACT_VALUE = ACT_VALUE % 1000;
         mdm_write_p (2, '.');
         putc('.');
         c = (int8) (( ACT_VALUE / 100 ) % 100 ) + 48;
         mdm_write_p ( 2, c);
         putc(c);
         c = (int8) (( ACT_VALUE / 10 ) % 10 ) + 48;
         mdm_write_p ( 3, c);
         putc(c);
         c = (int8) ( ACT_VALUE % 10 ) + 48;
         mdm_write_p ( 4, c);
         putc(c);
         mdm_write_p (5, 'V');
         putc('V');
         putc(0x0A);
         putc(0x0D);
         delay_ms(250);
		}

		else
		{
		blink();
		blank();
		show_12345();
		blank();
		show_ascii();
		blank();
		show_hello();
		blank();
		}
	}
}
